/* GStreamer
 * Copyright (C) <2004> Jeremy Simon <jsimon13@yahoo.fr>
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef __GST_MONKEYSDEC_H__
#define __GST_MONKEYSDEC_H__

#include <gst/gst.h>
#include <gst/bytestream/bytestream.h>

#include <mac/All.h>
#include <mac/GlobalFunctions.h>
#include <mac/CharacterHelper.h>
#include <mac/MACLib.h>
#include <mac/IO.h>
#include <mac/APETag.h>

#include "monkeys_io.h"

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

typedef enum
{
  GST_MONKEYSDEC_STATE_INIT    = 0,
  GST_MONKEYSDEC_STATE_PLAY    = 1,
  GST_MONKEYSDEC_STATE_SEEK    = 2,
  GST_MONKEYSDEC_STATE_DISCONT = 3
}
GstMonkeysState;

#define GST_TYPE_MONKEYSDEC  	     (gst_monkeysdec_get_type())
#define GST_MONKEYSDEC(obj)  	     (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_MONKEYSDEC,GstMonkeysDec))
#define GST_MONKEYSDEC_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_MONKEYSDEC,GstMonkeysDec))
#define GST_IS_MONKEYSDEC(obj) 	     (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_MONKEYSDEC))
#define GST_IS_MONKEYSDEC_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_MONKEYSDEC))

#define BLOCK_TO_RETRIEVE	512

typedef struct _GstMonkeysDec      GstMonkeysDec;
typedef struct _GstMonkeysDecClass GstMonkeysDecClass;

struct _GstMonkeysDec
{
  GstElement element;

  GstPad *sinkpad, *srcpad;
  guint64 total_samples;
  guint64 seek_to;
  guint state;
  guint block_align;
  
  guint channels;
  guint frequency;
  guint depth;  
	
  IAPEDecompress *decomp;
/*  CAPETag *tag;*/
	  
  sinkpad_CIO *io;
};

struct _GstMonkeysDecClass
{
  GstElementClass parent_class;
};

GType gst_monkeysdec_get_type(void);


#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __GST_MONKEYSDEC_H__ */
